#  (2025-03-19)


### Bug Fixes

* 更新许可证文件中的版权信息 ([70bcf1f](https://github.com/treerootboy/mcp-airflow/commit/70bcf1f9929695793ab0d4fe589747e167937c57))


### Features

* 第一版提交 ([a2125b7](https://github.com/treerootboy/mcp-airflow/commit/a2125b7bdfd9bd5e03f9dd1036ad0ea3115850cb))
* 实现全局DAG运行日报功能 ([a1bca63](https://github.com/treerootboy/mcp-airflow/commit/a1bca6347fa8181e8350495ec099205486ad63cc))
* 添加 MIT 许可证文件 ([39a1777](https://github.com/treerootboy/mcp-airflow/commit/39a177715c084a7c25caa5dc5288d4e53e71034f))
* 添加项目文档和配置文件以支持 Airflow MCP 服务器 ([433a5a4](https://github.com/treerootboy/mcp-airflow/commit/433a5a477cfb227839130338a4973a91b95ba45c))
* 支持通过环境变量配置 Airflow API 基础 URL 和认证信息 ([22891fa](https://github.com/treerootboy/mcp-airflow/commit/22891fa764babf85fc9d654e89114f24dc397cc6))
* 支持在回填工具中使用日期范围进行多次回填 ([8d1d9d0](https://github.com/treerootboy/mcp-airflow/commit/8d1d9d0cab3570cdac309e69abf67e4edbb64258))
* Add backfill tool to Airflow MCP server ([f68ff15](https://github.com/treerootboy/mcp-airflow/commit/f68ff150599e5c2233ad31daf61953b277cd6932))
* add date range support for daily report ([48fa337](https://github.com/treerootboy/mcp-airflow/commit/48fa3378268f7510e78d3140702e4f8157eb2b15))
* enhance daily report with error analysis ([dcfea70](https://github.com/treerootboy/mcp-airflow/commit/dcfea705a74cd679095dc737161db7a75ad91b54))
* enhance daily report with multi-day statistics ([b80dea8](https://github.com/treerootboy/mcp-airflow/commit/b80dea8f84b63f92a8c05d8f8ecbb58f239084f4))



